@@ -84,7 +84,7 @@ module.exports = function (grunt) {
             ]
         };
 
-        grunt.config.merge({ 'copy': config });
+        grunt.config.merge({ copy: config });
         grunt.registerTask('install:' + Lang, 'install language directory into a custom location', function () {
             if (!grunt.option('htdoc')) {
                 grunt.fail.fatal('Need --htdoc option to be set');
